@@ -1,26 +1,37 @@
-#' Calculate the use report (UR) per species
+#' Calculate the use reports (UR) per species
 #'
-#' This function allows you to calculate the use report (UR) per secies, a common metric for ethnobotany studies.
+#' Allows users to calculate the use reports (UR) per secies, a common metric for ethnobotany studies.
 #' @param data is an ethnobotany data set with column 1 'informant' and 2 'sp_name' as row identifiers of informants and of species names respectively.
 #' The rest of the columns are the identified ethnobotany use categories. The data should be populated with counts of uses per person (should be 0 or 1 values).
 #' @keywords ethnobotany, cultural value, use report
 #'
 #' @importFrom magrittr %>%
-#' @importFrom plyr ddply 
-#' @importFrom plyr summarise 
+#' @importFrom dplyr filter summarize select left_join group_by 
 #' @importFrom assertthat validate_that
 #' @importFrom assertthat see_if
 #' 
 #' @examples
 #' 
+#' #Use built-in ethnobotany data example
 #' URs(ethnobotanydata)
 #' 
+#' #Generate random dataset of three informants uses for four species
+#' eb_data <- data.frame(replicate(10,sample(0:1,20,rep=TRUE)))
+#' names(eb_data) <- gsub(x = names(eb_data), pattern = "X", replacement = "Use_")  
+#' eb_data$informant<-sample(c('User_1', 'User_2', 'User_3'), 20, replace=TRUE)
+#' eb_data$sp_name<-sample(c('sp_1', 'sp_2', 'sp_3', 'sp_4'), 20, replace=TRUE)
+#' URs(eb_data)
+#' 
 #' @export URs
 URs <- function(data) {
-    if (!requireNamespace("plyr", quietly = TRUE)) {
-        stop("Package \"plyr\" needed for this function to work. Please install it.",
+    if (!requireNamespace("dplyr", quietly = TRUE)) {
+        stop("Package \"dplyr\" needed for this function to work. Please install it.",
             call. = FALSE)
     }
+  if (!requireNamespace("magrittr", quietly = TRUE)) {
+    stop("Package \"magrittr\" needed for this function to work. Please install it.",
+         call. = FALSE)
+  }
   
   URdata <- URs <- sp_name <- informant <- URps <- NULL # Setting the variables to NULL first, appeasing R CMD check
   
@@ -31,7 +42,7 @@ URs <- function(data) {
   assertthat::validate_that(is.factor(data$informant), msg = "The \"informant\" is not a factor variable. Transform it.")
   assertthat::validate_that(is.factor(data$sp_name), msg = "The \"sp_name\" is not a factor variable. Transform it.")
   
-  assertthat::validate_that(all(sum(dplyr::select(data, -informant, -sp_name)>0)) , msg = "The sum of all UR is not greater than zero. Perhaps not all uses have values or are not numeric.")
+  assertthat::validate_that(all(sum(dplyr::select(data, -informant, -sp_name)>0)) , msg = "The sum of all UR is not greater than zero. Perhaps not all uses have values or are they are not numeric.")
   
   ## Use 'complete.cases' from stats to get to the collection of obs without NA
   data_complete<-data[stats::complete.cases(data), ]
@@ -39,13 +50,11 @@ URs <- function(data) {
   assertthat::see_if(length(data_complete) == length(data), msg = "Some of your observations included \"NA\" and were removed. Consider using \"0\" instead.")
   
    URdata <- data #create subset-able data
+   
    URdata$URps <- dplyr::select(URdata, -informant, -sp_name) %>% rowSums()
-    data_URs <- plyr::ddply(URdata, ~sp_name,
-                plyr::summarise, URs = sum(URps))
+    URs <- URdata %>% dplyr::group_by(sp_name) %>%
+                dplyr::summarize (URs = sum(URps))%>%
+      dplyr::arrange(-URs) 
     
-    #change sort order
-    URs <- data_URs[order(-data_URs$URs),] 
-    
-    print("Total number of Use Reports (URs) for each species in the data set")
-    print(URs)
+    print(as.data.frame(URs))
 }
